@@ -1,4 +1,4 @@
-"""
+'''
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 # BNode
 Module | `bnode.py`
@@ -8,13 +8,14 @@ May 21, 2020
 
 Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
-"""
+'''
 
 __all__ = ['BNode']
 
 from ...uuid_generator import generate_uuid
 from .identifier import Identifier
 
+
 class BNode(Identifier):
     __slots__ = ()
 
@@ -22,13 +23,13 @@ class BNode(Identifier):
         return str(self)
 
     def __getnewargs__(self):
-        return (str(self), )
+        return (str(self))
 
     def __new__(cls, value=None):
         return Identifier.__new__(cls, value or generate_uuid())
 
     def __reduce__(self):
-        return (BNode, (str(self),))
+        return (BNode, (str(self)))
 
     def __repr__(self):
         return "BNode('%s')" % self
\ No newline at end of file
