@@ -1,4 +1,4 @@
-"""
+'''
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 # URIRef
 Module | `uriref.py`
@@ -8,15 +8,14 @@ May 21, 2020
 
 Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
-"""
+'''
 
 __all__ = ['URIRef']
 
-import logging
+from logging import getLogger
 
 from .identifier import Identifier
 
-_logger = logging.getLogger(__name__)
 
 class URIRef(Identifier):
     _invalid_chars = '<>" {}|\\^`'
@@ -34,21 +33,21 @@ class URIRef(Identifier):
         return self.__class__(str(self) + other)
 
     def __getnewargs__(self):
-        return (str(self), )
+        return (str(self))
 
     def __mod__(self, other):
         return self.__class__(str(self) % other)
 
     def __new__(cls, value):
         if not URIRef.is_valid(value):
-            _logger.warning('%s does not look like a valid URI, trying to serialize this will break.' % value)
+            getLogger(__name__).warning('%s does not look like a valid URI, trying to serialize this will break.' % value)
         return str.__new__(cls, value)
 
     def __radd__(self, other):
         return self.__class__(other + str(self))
 
     def __reduce__(self):
-        return (URIRef, (str(self),))
+        return (URIRef, (str(self)))
 
     def __repr__(self):
         return "URIRef('%s')" % str(self)
