@@ -13,4 +13,4 @@ Copyright © Semantyk 2020. All rights reserved.\
 __all__ = ['Node']
 
 class Node(object):
-    pass
+    __slots__ = ()
