@@ -10,4 +10,15 @@
 # May 13, 2020
 # 
 # Copyright © Semantyk 2020. All rights reserved.
-##################################################
\ No newline at end of file
+##################################################
+
+import sys
+import tkinter
+
+def main():
+    root = tkinter.Tk()
+    root.title('Semantyk')
+    root.resizable(width=False, height=False)
+    root.mainloop()
+if __name__ == '__main__': 
+    main()
\ No newline at end of file
